@@ -41,7 +41,8 @@ enum {
 	CDP_TLV_PORT			= 3,
 	CDP_TLV_CAPABILITIES		= 4,
 	CDP_TLV_SOFTWARE		= 5,
-	CDP_TLV_PLATFORM		= 6
+	CDP_TLV_PLATFORM		= 6,
+	CDP_TLV_NATIVEVLAN		= 10
 };
 
 #define CDP_ADDRESS_PROTO_IP 0xcc
